pub struct EdgesDataFrame<'a> { /* private fields */ }Available on crate feature
polars only.Expand description
A wrapper around a Polars DataFrame that represents edges in a graph.
The EdgesDataFrame struct provides a view into a Polars DataFrame with associated
source and target index columns.
This is used to facilitate operations on edge data within a DataFrame.
Examples
use graphster::prelude::EdgesDataFrame;
use polars::prelude::*;
let s0 = Series::new("source", &[0, 1, 2]);
let s1 = Series::new("target", &[1, 2, 0]);
let s2 = Series::new("weight", &[1.0, 2.0, 3.0]);
let df = DataFrame::new(vec![s0, s1, s2]).unwrap();
let edges_df = EdgesDataFrame::new(&df, "source", "target");Implementations
Sourceimpl EdgesDataFrame<'_>
impl EdgesDataFrame<'_>
Sourcepub fn new<'a>(
dataframe: &'a DataFrame,
source_index_column: &'a str,
target_index_column: &'a str,
) -> EdgesDataFrame<'a>
pub fn new<'a>( dataframe: &'a DataFrame, source_index_column: &'a str, target_index_column: &'a str, ) -> EdgesDataFrame<'a>
Creates a new EdgesDataFrame with the specified DataFrame, source index column,
and target index column.
Examples
use graphster::prelude::EdgesDataFrame;
use polars::prelude::*;
let s0 = Series::new("source", &[0, 1, 2]);
let s1 = Series::new("target", &[1, 2, 0]);
let s2 = Series::new("weight", &[1.0, 2.0, 3.0]);
let df = DataFrame::new(vec![s0, s1, s2]).unwrap();
let edges_df = EdgesDataFrame::new(&df, "source", "target");Trait Implementations
Sourceimpl<'a> Clone for EdgesDataFrame<'a>
impl<'a> Clone for EdgesDataFrame<'a>
Sourcefn clone(&self) -> EdgesDataFrame<'a>
fn clone(&self) -> EdgesDataFrame<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for EdgesDataFrame<'a>
impl<'a> Debug for EdgesDataFrame<'a>