pub enum AttributeKey {
Boolean(bool),
Int16(i16),
Int32(i32),
Int64(i64),
Int8(i8),
String(String),
UInt16(u16),
UInt32(u32),
UInt64(u64),
UInt8(u8),
Usize(usize),
}Expand description
An enumeration of possible keys for attributes in a graph.
AttributeKey defines various types of keys that are used in Graphster.
Each variant supports the .into() method for easy conversion from the respective data type.
Examples
use graphster::prelude::AttributeKey;
// Creating AttributeKey instances directly
let key1 = AttributeKey::String("example_key".to_string());
let key2 = AttributeKey::Int32(42);
// Creating AttributeKey instances using .into()
let key3: AttributeKey = "another_key".into();
let key4: AttributeKey = 100u64.into();The variants are:
Boolean(bool): Represents a boolean key.Int8(i8): Represents an 8-bit signed integer key.Int16(i16): Represents a 16-bit signed integer key.Int32(i32): Represents a 32-bit signed integer key.Int64(i64): Represents a 64-bit signed integer key.String(String): Represents a string key.UInt8(u8): Represents an 8-bit unsigned integer key.UInt16(u16): Represents a 16-bit unsigned integer key.UInt32(u32): Represents a 32-bit unsigned integer key.UInt64(u64): Represents a 64-bit unsigned integer key.Usize(usize): Represents ausizekey.
Variants
Boolean(bool)
Int16(i16)
Int32(i32)
Int64(i64)
Int8(i8)
String(String)
UInt16(u16)
UInt32(u32)
UInt64(u64)
UInt8(u8)
Usize(usize)